Walks every attachment in the list and reads its
name / mime-type / size-bytes into a tibble. Adds handle and
source list-columns (ADR-017).
Arguments
- x
A
pdfium_attachment_listfrompdf_attachments().- ...
Unused (S3 generic compatibility).
Walks every attachment in the list and reads its
name / mime-type / size-bytes into a tibble. Adds handle and
source list-columns (ADR-017).
A pdfium_attachment_list from pdf_attachments().
Unused (S3 generic compatibility).