Skip to contents

Wraps FPDFPage_GetAnnotIndex. Useful after pdf_annot_new() when you want to know the position of the freshly-created annotation inside the page's annot list (e.g. to coordinate with index-driven code paths).

Usage

pdf_annot_index(annot)

Arguments

annot

A pdfium_annot from pdf_annot_new() or pdf_annotations().

Value

Integer scalar — one-based annotation index on the parent page, or NA_integer_ if the annotation is not found.

See also