Returns the X coordinate of the destination for XYZ / FitR /
FitBH destinations; NA for view modes that don't carry one.
Wraps FPDFDest_GetLocationInPage.
Arguments
- bm
A
pdfium_bookmarkhandle frompdf_doc_bookmarks().
Returns the X coordinate of the destination for XYZ / FitR /
FitBH destinations; NA for view modes that don't carry one.
Wraps FPDFDest_GetLocationInPage.
A pdfium_bookmark handle from pdf_doc_bookmarks().