Returns the external file path when the bookmark action is
"remote_goto", "launch", or "embedded_goto", else
NA_character_. Wraps FPDFAction_GetFilePath.
Arguments
- bm
A
pdfium_bookmarkhandle frompdf_doc_bookmarks().
Returns the external file path when the bookmark action is
"remote_goto", "launch", or "embedded_goto", else
NA_character_. Wraps FPDFAction_GetFilePath.
A pdfium_bookmark handle from pdf_doc_bookmarks().