Returns the field's current value as text. For checkbox /
radio fields this is the export name when checked or "Off"
otherwise. Wraps FPDFAnnot_GetFormFieldValue.
Arguments
- field
A
pdfium_form_fieldhandle frompdf_form_fields().
Returns the field's current value as text. For checkbox /
radio fields this is the export name when checked or "Off"
otherwise. Wraps FPDFAnnot_GetFormFieldValue.
A pdfium_form_field handle from
pdf_form_fields().