Reset every form field in the document to its default value
Source:R/form_field_setters.R
pdf_form_reset.RdConvenience wrapper that calls pdf_form_field_clear() on
every form field in doc. PDFium has no public FORM_Reset
symbol, so this is implemented as a loop over the field list.
Arguments
- doc
A
pdfium_docfrompdf_doc_open(). Must be readwrite.