PDFium reports the type of each page object as an integer code
(0 = unknown, 1 = text, 2 = path, 3 = image, 4 = shading,
5 = form XObject). pdf_obj_type() returns the name; this
helper exposes the symmetric direction.
PDFium reports the type of each page object as an integer code
(0 = unknown, 1 = text, 2 = path, 3 = image, 4 = shading,
5 = form XObject). pdf_obj_type() returns the name; this
helper exposes the symmetric direction.