Walks every bookmark in the list and reads its metadata into a
tibble. Adds handle and source list-columns (ADR-017).
Arguments
- x
A
pdfium_bookmark_listfrompdf_doc_bookmarks().- ...
Unused (S3 generic compatibility).
Walks every bookmark in the list and reads its metadata into a
tibble. Adds handle and source list-columns (ADR-017).
A pdfium_bookmark_list from pdf_doc_bookmarks().
Unused (S3 generic compatibility).