Wraps FPDFPageObj_SetDashPhase. The full dash setter
pdf_path_set_dash() sets both the array and the phase in one
call; this fine-grained setter is useful when you want to tweak
the phase without re-supplying the (possibly-long) array.
See also
pdf_path_set_dash() for the array + phase setter.